@@ -8,7 +8,7 @@ use Carp ();
 use FFI::Platypus 1.00;
 
 # ABSTRACT: Object-oriented FFI interface to native stat and lstat
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 my $ffi = FFI::Platypus->new( api => 1 );
@@ -25,6 +25,7 @@ $ffi->mangler(sub { "stat__$_[0]" });
 $ffi->attach( '_stat'  => ['string'] => 'opaque' );
 $ffi->attach( '_fstat' => ['int',  ] => 'opaque' );
 $ffi->attach( '_lstat' => ['string'] => 'opaque' );
+$ffi->attach( '_new'   => []         => 'opaque' );
 
 
 sub new
@@ -36,6 +37,8 @@ sub new
   { $ptr = _fstat(fileno($file)) }
   elsif(!is_ref($file) && defined $file)
   { $ptr = $options{symlink} ? _lstat($file) : _stat($file) }
+  elsif(!defined $file)
+  { $ptr = _new() }
   else
   { Carp::croak("Tried to stat something whch is neither a glob reference nor a plain string") }
 
@@ -110,7 +113,7 @@ FFI::C::Stat - Object-oriented FFI interface to native stat and lstat
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -149,9 +152,11 @@ You can bind C<my_cfunction> like this:
 
  my $stat = FFI::C::Stat->new(*HANDLE,   %options);
  my $stat = FFI::C::Stat->new($filename, %options);
+ my $stat = FFI::C::Stat->new;
 
 You can create a new instance of this class by calling the new method and passing in
-either a file or directory handle, or by passing in the filename path.
+either a file or directory handle, or by passing in the filename path.  If you do
+not pass anything then an uninitialized stat will be returned.
 
 Options:
 
@@ -191,6 +196,10 @@ Perl:
    return FFI::C::Stat->clone($ptr);
  });
 
+The behavior of passing in C<undef> prior to version 0.03 was undefined and could cause a
+crash.  In version 0.03 and later passing in C<undef> will return a stat object with all
+of the bits set to zero (0).
+
 =head1 PROPERTIES
 
 =head2 dev
@@ -277,7 +286,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Graham Ollis.
+This software is copyright (c) 2021-2023 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
